@@ -11,7 +11,7 @@ use base qw(App::Followme::Module);
 use File::Spec::Functions qw(catfile);
 use App::Followme::FIO;
 
-our $VERSION = "2.02";
+our $VERSION = "2.03";
 
 #----------------------------------------------------------------------
 # Read the default parameter values
@@ -66,6 +66,16 @@ sub list_urls {
     return @urls;
 }
 
+#----------------------------------------------------------------------
+# Initialize the extension
+
+sub setup {
+    my ($self) = @_;
+
+    $self->{extension} = $self->{web_extension};
+    return;
+}
+
 1;
 __END__
 
