@@ -11,7 +11,7 @@ use base qw(App::Followme::Module);
 use File::Spec::Functions qw(catfile);
 use App::Followme::FIO;
 
-our $VERSION = "2.02";
+our $VERSION = "2.03";
 
 #----------------------------------------------------------------------
 # Read the default parameter values
@@ -85,6 +85,16 @@ sub find_location {
     return;
 }
 
+#----------------------------------------------------------------------
+# Initialize the extension
+
+sub setup {
+    my ($self) = @_;
+
+    $self->{extension} = $self->{web_extension};
+    return;
+}
+
 #----------------------------------------------------------------------
 # Read page and strip comments
 
@@ -111,12 +121,23 @@ sub strip_comments {
 }
 
 #----------------------------------------------------------------------
-# Parse prototype and page and combine them
+# Strip file of comments and combine with prototype
 
 sub update_file {
     my ($self, $file, $prototype) = @_;
 
     my $page = $self->strip_comments($file, 0);
+    $page = $self->update_page($page, $prototype);
+    fio_write_page($file, $page);
+
+    return;
+}
+
+#----------------------------------------------------------------------
+# Parse prototype and page and combine them
+
+sub update_page {
+    my ($self, $page, $prototype) = @_;
 
     my @output;
     my $notfound;
@@ -144,8 +165,7 @@ sub update_file {
 
     die "Could not locate tags\n" if $notfound;
 
-    fio_write_page($file, join('', @output));
-    return;
+    return join('', @output);
 }
 
 #----------------------------------------------------------------------
