@@ -23,7 +23,7 @@ our @EXPORT = qw(fio_filename_to_url fio_flatten
                  fio_split_filename fio_to_file 
                  fio_visit fio_write_page);
 
-our $VERSION = "2.02";
+our $VERSION = "2.03";
 
 #----------------------------------------------------------------------
 # Calculate the check sum for a file
@@ -241,7 +241,7 @@ sub fio_match_patterns {
 # Get the most recently modified web file in a directory
 
 sub fio_most_recent_file {
-    my ($directory, $pattern) = @_;
+    my ($directory, $pattern, $exclude_index) = @_;
 
     my ($filenames, $directories) = fio_visit($directory);
 
@@ -253,6 +253,11 @@ sub fio_most_recent_file {
         my ($dir, $file) = fio_split_filename($filename);
         next unless fio_match_patterns($file, $globs);
 
+        if ($exclude_index) {
+            my ($base, $ext) = split(/\./, $file, 2);
+            next if $base eq 'index';
+        }
+
         my $file_date = fio_get_date($filename);
 
         if ($file_date > $newest_date) {
@@ -410,6 +415,8 @@ sub fio_write_page {
     print $fd $page;
     close($fd);
 
+    die "Didn't write page $filename\n" unless -e $filename;
+
     return;
 }
 
@@ -485,11 +492,12 @@ and the empty string if the directory could not be created.
 Return 1 (Perl true) if a filename matches a Perl pattern in a list of
 patterns.
 
-=item $filename = fio_most_recent_file($directory, $patterns);
+=item $filename = fio_most_recent_file($directory, $patterns, $exclude_index);
 
 
 Return the most recently modified file in a directory whose name matches
-a comma separated list of Unix wildcard patterns.
+a comma separated list of Unix wildcard patterns. Exclude the index if 
+the last argument is true.
 
 =item $str = fio_read_page($filename, $binmode);
 
