@@ -10,7 +10,7 @@ use base qw(App::Followme::FileData);
 use App::Followme::FIO;
 use App::Followme::Web;
 
-our $VERSION = "2.02";
+our $VERSION = "2.03";
 
 #----------------------------------------------------------------------
 # Read the default parameter values
@@ -21,7 +21,6 @@ sub parameters {
     return (
             body_tag => 'primary',
             metadata_tag => 'meta',
-            extension => '',
            );
 }
 
@@ -76,16 +75,6 @@ sub fetch_sections {
     return \%section;
 }
 
-#----------------------------------------------------------------------
-# Initialize the extension if unset
-
-sub setup {
-    my ($self) = @_;
-
-    $self->{extension} ||= $self->{web_extension};
-    return;
-}
-
 1;
 
 =pod
